#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 focus
version:              1.0.3.2
visibility:           public
id:                   focus-1.0.3.2-GvHulYJKvb0IU5E5h6uwlC
key:                  focus-1.0.3.2-GvHulYJKvb0IU5E5h6uwlC
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/focus
synopsis:
    A general abstraction for manipulating elements of container data structures

description:
    An API for construction of free-form strategies of access and manipulation of 
    elements of arbitrary data structures.
    It allows to implement efficient composite patterns, e.g., 
    a simultaneous update and lookup of an element, 
    and even more complex things.
    Strategies are meant to be interpreted by the host data structure libraries.
    Thus they allow to implement all access and modification patterns of
    a data structure with just a single function,
    which interprets strategies.
    This library provides pure and monadic interfaces,
    so it supports both immutable and mutable data structures.

category:             Containers, Data
abi:                  637b78dc3376b7e6190b479f59cc34c6
exposed:              True
exposed-modules:      Focus
hidden-modules:       Focus.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/focus-1.0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/focus-1.0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/focus-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-focus
hs-libraries:         HSfocus-1.0.3.2-GvHulYJKvb0IU5E5h6uwlC
depends:              base-4.18.2.1 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-focus/html/focus.haddock
haddock-html:         /usr/share/doc/haskell-focus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

